pub struct FixedPointExecutionPlanCache { /* private fields */ }Expand description
Execution-plan cache keyed by backend identity, analysis family, graph layout, and frontier-density family.
Implementations
Sourceimpl FixedPointExecutionPlanCache
impl FixedPointExecutionPlanCache
Sourcepub fn with_max_entries(max_entries: usize) -> Self
pub fn with_max_entries(max_entries: usize) -> Self
Create an empty execution-plan cache with an explicit entry bound.
Sourcepub fn get_or_plan(
&mut self,
backend: &dyn VyreBackend,
kind: FixedPointAnalysisKind,
graph: &FixedPointForwardGraph,
frontier_density: FrontierDensityTelemetry,
) -> Result<FixedPointExecutionPlan, String>
pub fn get_or_plan( &mut self, backend: &dyn VyreBackend, kind: FixedPointAnalysisKind, graph: &FixedPointForwardGraph, frontier_density: FrontierDensityTelemetry, ) -> Result<FixedPointExecutionPlan, String>
Return a plan for this backend, graph, analysis kind, and density bucket.
Sourcepub fn stats(&self) -> FixedPointExecutionPlanCacheStats
pub fn stats(&self) -> FixedPointExecutionPlanCacheStats
Return point-in-time plan-cache counters.