pub struct FixedPointResidentBatchStats {Show 14 fields
pub graph_cache: FixedPointResidentGraphCacheStats,
pub execution_plan_cache: FixedPointExecutionPlanCacheStats,
pub frontier_allocations: u64,
pub frontier_reuses: u64,
pub frontier_clears: u64,
pub resident_dispatches: u64,
pub frontier_upload_bytes: u64,
pub result_readback_bytes: u64,
pub resident_graph_cold_uploads: u64,
pub resident_graph_warm_reuses: u64,
pub resident_graph_upload_bytes: u64,
pub resident_graph_avoided_upload_bytes: u64,
pub frontier_resident: bool,
pub frontier_bytes: usize,
}Expand description
Runtime counters for FixedPointResidentBatch.
Fields
graph_cache: FixedPointResidentGraphCacheStatsResident graph cache counters.
execution_plan_cache: FixedPointExecutionPlanCacheStatsExecution-plan cache counters.
frontier_allocations: u64Resident frontier allocation or resize events observed by this facade.
frontier_reuses: u64Solves that reused the existing resident frontier allocation.
frontier_clears: u64Resident frontier clears performed by FixedPointResidentBatch::free_all.
resident_dispatches: u64Successful resident fixed-point dispatches executed through this facade.
frontier_upload_bytes: u64Host-to-device frontier seed bytes uploaded through resident solves.
result_readback_bytes: u64Device-to-host result bytes read back through resident solves.
resident_graph_cold_uploads: u64Resident graph cache misses observed by this facade.
resident_graph_warm_reuses: u64Resident graph cache hits observed by this facade.
resident_graph_upload_bytes: u64Resident graph bytes uploaded by cold graph-cache misses.
resident_graph_avoided_upload_bytes: u64Resident graph upload bytes avoided by warm graph-cache hits.
frontier_resident: boolWhether the reusable resident frontier pair is currently allocated.
frontier_bytes: usizeCurrent resident frontier byte width.
Implementations
Sourceimpl FixedPointResidentBatchStats
impl FixedPointResidentBatchStats
Sourcepub const fn resident_graph_reuse_telemetry(self) -> ResidentGraphReuseTelemetry
pub const fn resident_graph_reuse_telemetry(self) -> ResidentGraphReuseTelemetry
Backend-neutral resident graph reuse telemetry for this batch snapshot.