pub struct FixedPointResidentGraphCacheStats {
pub hits: u64,
pub misses: u64,
pub resident_uploads: u64,
pub resident_upload_bytes: u64,
pub resident_avoided_upload_bytes: u64,
pub evictions: u64,
pub retained_bytes: usize,
pub entries: usize,
}Expand description
Runtime counters for super::FixedPointResidentGraphCache.
Fields
hits: u64Successful lookups that avoided resident graph upload.
misses: u64Lookups that uploaded invariant graph buffers.
resident_uploads: u64Resident graph uploads performed by this cache.
resident_upload_bytes: u64Cumulative resident graph bytes uploaded by this cache.
resident_avoided_upload_bytes: u64Cumulative resident graph upload bytes avoided by cache hits.
evictions: u64Resident graph entries evicted to stay within the retained-byte limit.
retained_bytes: usizeCurrent resident graph bytes retained by the cache.
entries: usizeCurrent resident graph entry count.
Implementations
Sourceimpl FixedPointResidentGraphCacheStats
impl FixedPointResidentGraphCacheStats
Sourcepub const fn resident_graph_reuse_telemetry(self) -> ResidentGraphReuseTelemetry
pub const fn resident_graph_reuse_telemetry(self) -> ResidentGraphReuseTelemetry
Backend-neutral resident graph reuse telemetry for this cache snapshot.