pub struct FixedPointScratch { /* private fields */ }Expand description
Caller-owned scratch for Weir fixed-point GPU wrappers.
Implementations
Sourceimpl FixedPointScratch
impl FixedPointScratch
Sourcepub fn with_capacities(
frontier_words: usize,
output_slots: usize,
resource_slots: usize,
) -> Result<Self, String>
pub fn with_capacities( frontier_words: usize, output_slots: usize, resource_slots: usize, ) -> Result<Self, String>
Allocate reusable fixed-point scratch with enough retained capacity for a known hot loop shape.
frontier_words sizes both the current and next frontier word buffers.
The byte frontier buffer is pre-sized to the exact little-endian byte
representation capacity used by dispatch wrappers. output_slots
preallocates reusable backend output vectors, and resource_slots
preallocates the dispatch resource list plus retained static input
byte slots for invariant graph buffers.
Sourcepub fn output_slot_count(&self) -> usize
pub fn output_slot_count(&self) -> usize
Number of backend output slots currently retained by this scratch.
Sourcepub fn output_slot_capacity(&self) -> usize
pub fn output_slot_capacity(&self) -> usize
Current retained capacity for backend output slots.
Sourcepub fn static_input_slot_capacity(&self) -> usize
pub fn static_input_slot_capacity(&self) -> usize
Current retained capacity for static dispatch input byte slots.
Sourcepub fn frontier_byte_capacity(&self) -> usize
pub fn frontier_byte_capacity(&self) -> usize
Current frontier byte-buffer capacity retained by this scratch.
Sourcepub fn frontier_word_capacity(&self) -> usize
pub fn frontier_word_capacity(&self) -> usize
Current frontier word-buffer capacity retained by this scratch.
Sourcepub fn next_word_capacity(&self) -> usize
pub fn next_word_capacity(&self) -> usize
Current decoded-next-word capacity retained by this scratch.
Sourcepub fn resource_capacity(&self) -> usize
pub fn resource_capacity(&self) -> usize
Current dispatch resource-list capacity retained by this scratch.
Sourcepub fn alternate_resource_capacity(&self) -> usize
pub fn alternate_resource_capacity(&self) -> usize
Current alternate dispatch resource-list capacity retained by this scratch.
Sourcepub fn edge_kind_mask_capacity(&self) -> usize
pub fn edge_kind_mask_capacity(&self) -> usize
Current filtered-edge-kind mask capacity retained by this scratch.
Sourcepub fn reverse_offset_capacity(&self) -> usize
pub fn reverse_offset_capacity(&self) -> usize
Current reverse-CSR offset capacity retained by this scratch.
Sourcepub fn reverse_target_capacity(&self) -> usize
pub fn reverse_target_capacity(&self) -> usize
Current reverse-CSR target capacity retained by this scratch.
Sourcepub fn frontier_density(&self) -> FrontierDensityTelemetry
pub fn frontier_density(&self) -> FrontierDensityTelemetry
Latest fixed-point frontier density counters for this scratch session.