Module live

Module live 

Live-variable analysis (DF-2 backward variant).

Prepare a graph for backward live-variable closure:

use weir::live::prepare_live_graph;

let graph = prepare_live_graph(
    2,
    &[0, 1, 1],
    &[1],
    &[0xFFFF_FFFF],
).unwrap();
assert_eq!(graph.node_count(), 2);

Structs

LiveFamily
Liveness
Marker type for the live-variables dataflow primitive.

Functions

live_closure_borrowed_into_result_with_scratch_via
live_closure_borrowed_into_via
live_closure_borrowed_into_with_scratch_via
live_closure_borrowed_via
live_closure_plan_borrowed_into_result_with_scratch_via
live_closure_plan_borrowed_into_with_scratch_via
live_closure_prepared_borrowed_into_result_with_scratch_via
live_closure_prepared_borrowed_into_with_scratch_via
live_closure_resident_plan_with_backend_scratch
live_closure_resident_plan_with_backend_scratch_into
live_closure_resident_plan_with_reusable_frontier_scratch
live_closure_resident_plan_with_reusable_frontier_scratch_into
live_closure_resident_plan_with_reusable_frontier_scratch_sequence_window
live_closure_resident_plan_with_reusable_frontier_scratch_sequence_window_into
live_closure_resident_plan_with_scratch
live_closure_resident_plan_with_scratch_into
live_closure_via
live_step
Build one backward live-variable propagation step over a reversed graph.
prepare_live_graph
Prepare invariant reversed-control graph buffers once for live analysis.
prepare_live_graph_into
Repack invariant live-variable graph buffers into an existing prepared graph.
prepare_live_graph_into_with_scratch
Repack invariant live-variable graph buffers into an existing prepared graph using caller-owned scratch for the reverse CSR build.
prepare_live_graph_with_scratch
Prepare invariant reversed-control graph buffers once using caller-owned scratch for the reverse CSR build.
prepare_live_plan
Prepare invariant live graph buffers and emitted Program once.
prepare_live_plan_into
Repack live-variable graph buffers and refresh the emitted Program in place.
prepare_live_plan_into_with_scratch
Repack live-variable graph buffers and refresh the emitted Program in place using caller-owned scratch for the reverse CSR build.
prepare_live_plan_with_scratch
Prepare invariant live graph buffers and emitted Program once using caller-owned scratch for the reverse CSR build.