Module reaching_def

Module reaching_def 

Reaching-definitions query packed as a bitset.

Build a reaching-def query Program:

use weir::reaching_def::reaching_def;

let program = reaching_def(4, "gen_kill_in", "use_set", "out");

reaching_def - reaching-definitions query packed as a bitset.

Per use site u, return the set of definitions that reach u (i.e. there’s a CFG path from def to use with no intervening def of the same variable). This is the bitset dataflow consumers read for the uses_of($def) predicate’s complement direction.

Structs

ReachingDef
Soundness marker for reaching_def.

Functions

reaching_def
Build a reaching-def query Program.