Module resident_cache_identity

Module resident_cache_identity 

Structs

ResidentGraphCacheIdentity
Backend-neutral resident graph cache identity shared by IFDS and fixed-point resident caches.
ResidentGraphCacheMissEvidence
Adjacent cache identity evidence used to explain resident graph misses.

Enums

ResidentGraphCacheDomain
Resident graph cache domain participating in shared cache identity.
ResidentGraphCacheMissReason
Backend-neutral resident cache-miss reason for diagnostics and release evidence.