pub struct ResidentGraphCacheMissEvidence {
pub total_entries: usize,
pub same_domain_entries: usize,
pub same_backend_entries: usize,
pub same_layout_entries: usize,
pub same_shape_entries: usize,
}Expand description
Adjacent cache identity evidence used to explain resident graph misses.
Fields
total_entries: usizeTotal resident graph cache entries inspected.
same_domain_entries: usizeEntries in the same resident graph domain.
same_backend_entries: usizeEntries with the same domain, backend id, and backend version.
same_layout_entries: usizeEntries with the same domain, backend identity, and layout hash.
same_shape_entries: usizeEntries with matching domain, backend, layout, node, edge, and frontier word counts.
Implementations
Sourceimpl ResidentGraphCacheMissEvidence
impl ResidentGraphCacheMissEvidence
Sourcepub fn from_identities<'a>(
cached: impl Iterator<Item = &'a ResidentGraphCacheIdentity>,
requested: &ResidentGraphCacheIdentity,
) -> Self
pub fn from_identities<'a>( cached: impl Iterator<Item = &'a ResidentGraphCacheIdentity>, requested: &ResidentGraphCacheIdentity, ) -> Self
Build miss evidence from cache identities adjacent to a requested key.