pub struct FixedPointExecutionPlan {
pub node_count: u32,
pub edge_count: u32,
pub layout_hash: u64,
pub retained_graph_bytes: usize,
pub frontier_bytes_per_iteration: usize,
pub average_degree_ppm: u64,
pub frontier_density: FrontierDensityTelemetry,
pub execution_mode: FrontierExecutionMode,
}Expand description
Shape and memory facts used to choose a fixed-point execution family.
Fields
node_count: u32Dispatch-domain nodes.
edge_count: u32Dispatch-domain CSR edges.
layout_hash: u64Stable normalized graph layout hash when available.
retained_graph_bytes: usizeRetained invariant graph bytes for the prepared plan.
frontier_bytes_per_iteration: usizeFrontier bytes transferred per host-visible iteration.
average_degree_ppm: u64Average outgoing degree in parts per million.
frontier_density: FrontierDensityTelemetryLatest frontier density telemetry used by the decision.
execution_mode: FrontierExecutionModeSelected execution family for this graph and observed frontier.
Implementations
Sourceimpl FixedPointExecutionPlan
impl FixedPointExecutionPlan
Sourcepub fn estimated_iteration_io_bytes(self) -> Result<usize, String>
pub fn estimated_iteration_io_bytes(self) -> Result<usize, String>
Conservative bytes moved by one host-visible iteration.
Sourcepub fn should_use_resident_graph(self) -> bool
pub fn should_use_resident_graph(self) -> bool
Whether repeated runs should favor resident graph resources.