pub struct FixedPointResidentBatch { /* private fields */ }Expand description
Reusable resident fixed-point execution state.
Implementations
Sourceimpl FixedPointResidentBatch
impl FixedPointResidentBatch
pub fn reaching( &mut self, backend: &dyn VyreBackend, pipeline: Arc<dyn CompiledPipeline>, graph: &FixedPointForwardGraph, seed_bits: &[u32], max_iterations: u32, config: &DispatchConfig, ) -> Result<Vec<u32>, String>
Sourcepub fn reaching_into(
&mut self,
backend: &dyn VyreBackend,
pipeline: Arc<dyn CompiledPipeline>,
graph: &FixedPointForwardGraph,
seed_bits: &[u32],
max_iterations: u32,
config: &DispatchConfig,
result: &mut Vec<u32>,
) -> Result<(), String>
pub fn reaching_into( &mut self, backend: &dyn VyreBackend, pipeline: Arc<dyn CompiledPipeline>, graph: &FixedPointForwardGraph, seed_bits: &[u32], max_iterations: u32, config: &DispatchConfig, result: &mut Vec<u32>, ) -> Result<(), String>
Run reaching-definition closure into caller-owned result storage while
reusing cached graph resources, resident frontier buffers, host scratch,
and the caller’s final Vec<u32> allocation.
Sourcepub fn live(
&mut self,
backend: &dyn VyreBackend,
pipeline: Arc<dyn CompiledPipeline>,
graph: &FixedPointForwardGraph,
seed_bits: &[u32],
max_iterations: u32,
config: &DispatchConfig,
) -> Result<Vec<u32>, String>
pub fn live( &mut self, backend: &dyn VyreBackend, pipeline: Arc<dyn CompiledPipeline>, graph: &FixedPointForwardGraph, seed_bits: &[u32], max_iterations: u32, config: &DispatchConfig, ) -> Result<Vec<u32>, String>
Run live-variable closure through cached resident graph resources and reusable resident frontier buffers.
Sourcepub fn live_into(
&mut self,
backend: &dyn VyreBackend,
pipeline: Arc<dyn CompiledPipeline>,
graph: &FixedPointForwardGraph,
seed_bits: &[u32],
max_iterations: u32,
config: &DispatchConfig,
result: &mut Vec<u32>,
) -> Result<(), String>
pub fn live_into( &mut self, backend: &dyn VyreBackend, pipeline: Arc<dyn CompiledPipeline>, graph: &FixedPointForwardGraph, seed_bits: &[u32], max_iterations: u32, config: &DispatchConfig, result: &mut Vec<u32>, ) -> Result<(), String>
Run live-variable closure into caller-owned result storage while
reusing cached graph resources, resident frontier buffers, host scratch,
and the caller’s final Vec<u32> allocation.
Sourcepub fn points_to_subset(
&mut self,
backend: &dyn VyreBackend,
pipeline: Arc<dyn CompiledPipeline>,
graph: &FixedPointForwardGraph,
seed_bits: &[u32],
max_iterations: u32,
config: &DispatchConfig,
) -> Result<Vec<u32>, String>
pub fn points_to_subset( &mut self, backend: &dyn VyreBackend, pipeline: Arc<dyn CompiledPipeline>, graph: &FixedPointForwardGraph, seed_bits: &[u32], max_iterations: u32, config: &DispatchConfig, ) -> Result<Vec<u32>, String>
Run points-to subset closure through cached resident graph resources and reusable resident frontier buffers.
Sourcepub fn points_to_subset_into(
&mut self,
backend: &dyn VyreBackend,
pipeline: Arc<dyn CompiledPipeline>,
graph: &FixedPointForwardGraph,
seed_bits: &[u32],
max_iterations: u32,
config: &DispatchConfig,
result: &mut Vec<u32>,
) -> Result<(), String>
pub fn points_to_subset_into( &mut self, backend: &dyn VyreBackend, pipeline: Arc<dyn CompiledPipeline>, graph: &FixedPointForwardGraph, seed_bits: &[u32], max_iterations: u32, config: &DispatchConfig, result: &mut Vec<u32>, ) -> Result<(), String>
Run points-to subset closure into caller-owned result storage while
reusing cached graph resources, resident frontier buffers, host scratch,
and the caller’s final Vec<u32> allocation.
Sourcepub fn slice(
&mut self,
backend: &dyn VyreBackend,
pipeline: Arc<dyn CompiledPipeline>,
graph: &FixedPointForwardGraph,
seed_bits: &[u32],
max_iterations: u32,
config: &DispatchConfig,
) -> Result<Vec<u32>, String>
pub fn slice( &mut self, backend: &dyn VyreBackend, pipeline: Arc<dyn CompiledPipeline>, graph: &FixedPointForwardGraph, seed_bits: &[u32], max_iterations: u32, config: &DispatchConfig, ) -> Result<Vec<u32>, String>
Run backward-slice closure through cached resident graph resources and reusable resident frontier buffers.
Sourcepub fn slice_into(
&mut self,
backend: &dyn VyreBackend,
pipeline: Arc<dyn CompiledPipeline>,
graph: &FixedPointForwardGraph,
seed_bits: &[u32],
max_iterations: u32,
config: &DispatchConfig,
result: &mut Vec<u32>,
) -> Result<(), String>
pub fn slice_into( &mut self, backend: &dyn VyreBackend, pipeline: Arc<dyn CompiledPipeline>, graph: &FixedPointForwardGraph, seed_bits: &[u32], max_iterations: u32, config: &DispatchConfig, result: &mut Vec<u32>, ) -> Result<(), String>
Run backward-slice closure into caller-owned result storage while
reusing cached graph resources, resident frontier buffers, host scratch,
and the caller’s final Vec<u32> allocation.
Sourcepub fn reaching_sequence_window(
&mut self,
backend: &dyn VyreBackend,
plan: &FixedPointAnalysisPlan,
seed_bits: &[u32],
max_iterations: u32,
) -> Result<Vec<u32>, String>
pub fn reaching_sequence_window( &mut self, backend: &dyn VyreBackend, plan: &FixedPointAnalysisPlan, seed_bits: &[u32], max_iterations: u32, ) -> Result<Vec<u32>, String>
Run reaching-definition closure through cached resident graph resources using backend resident sequence replay.
Sourcepub fn reaching_sequence_window_into(
&mut self,
backend: &dyn VyreBackend,
plan: &FixedPointAnalysisPlan,
seed_bits: &[u32],
max_iterations: u32,
result: &mut Vec<u32>,
) -> Result<(), String>
pub fn reaching_sequence_window_into( &mut self, backend: &dyn VyreBackend, plan: &FixedPointAnalysisPlan, seed_bits: &[u32], max_iterations: u32, result: &mut Vec<u32>, ) -> Result<(), String>
Run reaching-definition closure through backend resident sequence replay into caller-owned result storage.
Sourcepub fn live_sequence_window(
&mut self,
backend: &dyn VyreBackend,
plan: &FixedPointAnalysisPlan,
seed_bits: &[u32],
max_iterations: u32,
) -> Result<Vec<u32>, String>
pub fn live_sequence_window( &mut self, backend: &dyn VyreBackend, plan: &FixedPointAnalysisPlan, seed_bits: &[u32], max_iterations: u32, ) -> Result<Vec<u32>, String>
Run live-variable closure through cached resident graph resources using backend resident sequence replay.
Sourcepub fn live_sequence_window_into(
&mut self,
backend: &dyn VyreBackend,
plan: &FixedPointAnalysisPlan,
seed_bits: &[u32],
max_iterations: u32,
result: &mut Vec<u32>,
) -> Result<(), String>
pub fn live_sequence_window_into( &mut self, backend: &dyn VyreBackend, plan: &FixedPointAnalysisPlan, seed_bits: &[u32], max_iterations: u32, result: &mut Vec<u32>, ) -> Result<(), String>
Run live-variable closure through backend resident sequence replay into caller-owned result storage.
Sourcepub fn points_to_subset_sequence_window(
&mut self,
backend: &dyn VyreBackend,
plan: &FixedPointAnalysisPlan,
seed_bits: &[u32],
max_iterations: u32,
) -> Result<Vec<u32>, String>
pub fn points_to_subset_sequence_window( &mut self, backend: &dyn VyreBackend, plan: &FixedPointAnalysisPlan, seed_bits: &[u32], max_iterations: u32, ) -> Result<Vec<u32>, String>
Run points-to subset closure through cached resident graph resources using backend resident sequence replay.
Sourcepub fn points_to_subset_sequence_window_into(
&mut self,
backend: &dyn VyreBackend,
plan: &FixedPointAnalysisPlan,
seed_bits: &[u32],
max_iterations: u32,
result: &mut Vec<u32>,
) -> Result<(), String>
pub fn points_to_subset_sequence_window_into( &mut self, backend: &dyn VyreBackend, plan: &FixedPointAnalysisPlan, seed_bits: &[u32], max_iterations: u32, result: &mut Vec<u32>, ) -> Result<(), String>
Run points-to subset closure through backend resident sequence replay into caller-owned result storage.
Sourcepub fn slice_sequence_window(
&mut self,
backend: &dyn VyreBackend,
plan: &FixedPointAnalysisPlan,
seed_bits: &[u32],
max_iterations: u32,
) -> Result<Vec<u32>, String>
pub fn slice_sequence_window( &mut self, backend: &dyn VyreBackend, plan: &FixedPointAnalysisPlan, seed_bits: &[u32], max_iterations: u32, ) -> Result<Vec<u32>, String>
Run backward-slice closure through cached resident graph resources using backend resident sequence replay.
Sourcepub fn slice_sequence_window_into(
&mut self,
backend: &dyn VyreBackend,
plan: &FixedPointAnalysisPlan,
seed_bits: &[u32],
max_iterations: u32,
result: &mut Vec<u32>,
) -> Result<(), String>
pub fn slice_sequence_window_into( &mut self, backend: &dyn VyreBackend, plan: &FixedPointAnalysisPlan, seed_bits: &[u32], max_iterations: u32, result: &mut Vec<u32>, ) -> Result<(), String>
Run backward-slice closure through backend resident sequence replay into caller-owned result storage.
Sourceimpl FixedPointResidentBatch
impl FixedPointResidentBatch
Sourcepub fn with_max_retained_bytes(max_retained_bytes: usize) -> Self
pub fn with_max_retained_bytes(max_retained_bytes: usize) -> Self
Create a resident fixed-point batch facade with a soft graph-cache byte bound.
Sourcepub fn with_cache_bounds(
max_retained_bytes: usize,
max_execution_plans: usize,
) -> Self
pub fn with_cache_bounds( max_retained_bytes: usize, max_execution_plans: usize, ) -> Self
Create a resident fixed-point batch facade with explicit graph-cache byte and execution-plan entry bounds.
Sourcepub fn with_memory_budget(
max_retained_bytes: usize,
max_execution_plans: usize,
max_frontier_bytes: usize,
) -> Self
pub fn with_memory_budget( max_retained_bytes: usize, max_execution_plans: usize, max_frontier_bytes: usize, ) -> Self
Create a resident fixed-point batch facade with explicit graph-cache, execution-plan cache, and resident frontier byte bounds.
Sourcepub fn graph_cache(&self) -> &FixedPointResidentGraphCache
pub fn graph_cache(&self) -> &FixedPointResidentGraphCache
Inspect the resident graph cache.
Sourcepub fn graph_cache_stats(&self) -> FixedPointResidentGraphCacheStats
pub fn graph_cache_stats(&self) -> FixedPointResidentGraphCacheStats
Inspect resident graph cache counters.
Sourcepub fn execution_plan_cache_stats(&self) -> FixedPointExecutionPlanCacheStats
pub fn execution_plan_cache_stats(&self) -> FixedPointExecutionPlanCacheStats
Inspect execution-plan cache counters.
Sourcepub fn stats(&self) -> FixedPointResidentBatchStats
pub fn stats(&self) -> FixedPointResidentBatchStats
Inspect resident batch counters.
Sourcepub fn frontier_density(&self) -> FrontierDensityTelemetry
pub fn frontier_density(&self) -> FrontierDensityTelemetry
Latest host-observed frontier density from the last fixed-point solve.
Sourcepub fn recommended_frontier_execution_mode(&self) -> FrontierExecutionMode
pub fn recommended_frontier_execution_mode(&self) -> FrontierExecutionMode
Sparse/dense execution family recommended from the last solve’s frontier density.
Sourcepub fn execution_plan_for_prepared_graph(
&self,
graph: &FixedPointForwardGraph,
) -> Result<FixedPointExecutionPlan, String>
pub fn execution_plan_for_prepared_graph( &self, graph: &FixedPointForwardGraph, ) -> Result<FixedPointExecutionPlan, String>
Build a scale-aware execution plan for a prepared graph using the last observed frontier density.
Sourcepub fn cached_execution_plan_for_prepared_graph(
&mut self,
backend: &dyn VyreBackend,
kind: FixedPointAnalysisKind,
graph: &FixedPointForwardGraph,
) -> Result<FixedPointExecutionPlan, String>
pub fn cached_execution_plan_for_prepared_graph( &mut self, backend: &dyn VyreBackend, kind: FixedPointAnalysisKind, graph: &FixedPointForwardGraph, ) -> Result<FixedPointExecutionPlan, String>
Return a cached scale-aware execution plan for a prepared graph and analysis family using the last observed frontier density.
Sourcepub fn free_all(
&mut self,
backend: &dyn VyreBackend,
) -> Result<(), BackendError>
pub fn free_all( &mut self, backend: &dyn VyreBackend, ) -> Result<(), BackendError>
Free retained resident frontier and graph resources.