pub struct FixedPointResidentFrontierScratch { /* private fields */ }Expand description
Reusable resident frontier resources for fixed-point hot loops.
Implementations
Sourceimpl FixedPointResidentFrontierScratch
impl FixedPointResidentFrontierScratch
Sourcepub fn ensure_pair_refs(
&mut self,
backend: &dyn VyreBackend,
byte_len: usize,
) -> Result<(&Resource, &Resource), String>
pub fn ensure_pair_refs( &mut self, backend: &dyn VyreBackend, byte_len: usize, ) -> Result<(&Resource, &Resource), String>
Ensure the resident frontier pair exists with at least byte_len bytes.
Sourcepub fn ensure_inplace_refs(
&mut self,
backend: &dyn VyreBackend,
byte_len: usize,
) -> Result<(&Resource, &Resource), String>
pub fn ensure_inplace_refs( &mut self, backend: &dyn VyreBackend, byte_len: usize, ) -> Result<(&Resource, &Resource), String>
Ensure an in-place resident frontier and one u32 changed flag exist.
Sourcepub fn is_allocated(&self) -> bool
pub fn is_allocated(&self) -> bool
Whether both resident frontier resources are currently allocated.
Sourcepub fn clear(&mut self, backend: &dyn VyreBackend) -> Result<(), BackendError>
pub fn clear(&mut self, backend: &dyn VyreBackend) -> Result<(), BackendError>
Free resident frontier resources, preserving the scratch object itself.