pub struct ResidentIfdsParallelScratch<R> { /* private fields */ }Expand description
Reusable resident scratch buffers for parallel IFDS query batches.
Implementations
Sourceimpl<R> ResidentIfdsParallelScratch<R>
impl<R> ResidentIfdsParallelScratch<R>
Sourcepub fn words_per_query(&self) -> usize
pub fn words_per_query(&self) -> usize
Number of u32 words in each query frontier.
Sourcepub fn max_queries(&self) -> usize
pub fn max_queries(&self) -> usize
Maximum query count this scratch allocation can solve in one batch.
Sourcepub fn max_seed_facts(&self) -> usize
pub fn max_seed_facts(&self) -> usize
Maximum flattened seed facts this scratch can stage without allocating temporary resident seed buffers.
Sourcepub fn changed_iteration_capacity(&self) -> usize
pub fn changed_iteration_capacity(&self) -> usize
Maximum fixpoint iterations this scratch is budgeted to run without reallocating reusable resident storage.
Sourcepub fn frontier_byte_len(&self) -> usize
pub fn frontier_byte_len(&self) -> usize
Resident frontier matrix byte length.
Sourcepub fn changed_byte_len(&self) -> usize
pub fn changed_byte_len(&self) -> usize
Resident changed-flag byte length.
Sourcepub fn seed_triples_byte_len(&self) -> usize
pub fn seed_triples_byte_len(&self) -> usize
Resident seed-triple staging byte length.
Sourcepub fn seed_offsets_byte_len(&self) -> usize
pub fn seed_offsets_byte_len(&self) -> usize
Resident seed-offset staging byte length.
Sourcepub fn retained_bytes(&self) -> usize
pub fn retained_bytes(&self) -> usize
Total resident bytes retained by this reusable parallel scratch set.