pub struct DynamicPrimitiveSoundness {
pub op_id: String,
pub soundness: Soundness,
pub sanitizer_filter: bool,
}Expand description
Serializable soundness evidence for one primitive in a finding or release artifact.
Fields
op_id: StringStable primitive id, normally the vyre_harness::OpEntry::id.
soundness: SoundnessPrimitive soundness marker.
sanitizer_filter: boolWhether a downstream sanitizer/filter makes a MayOver primitive
safe for a zero-false-positive consumer.
Implementations
Sourceimpl DynamicPrimitiveSoundness
impl DynamicPrimitiveSoundness
Sourcepub fn new(
op_id: impl Into<String>,
soundness: Soundness,
) -> DynamicPrimitiveSoundness
pub fn new( op_id: impl Into<String>, soundness: Soundness, ) -> DynamicPrimitiveSoundness
Construct serializable primitive soundness evidence with no sanitizer filter.
Sourcepub fn with_sanitizer_filter(self) -> DynamicPrimitiveSoundness
pub fn with_sanitizer_filter(self) -> DynamicPrimitiveSoundness
Mark this primitive as bounded by an explicit downstream filter.